DNOTICIAS.PT

Funchal, 17° C

último comentário
100000000,00€ : 270000 madeirenses = 370...
por Edite Estrelada
" A melhor maneira de manter a fome de vencer é ficar em segundo"
Kelly Slater Surfista Ao i

# Registar-se

1. Dados de acesso
Correio electrónico: *
Um endereço de email válido. Todos os email deste sistema irão ser enviados para este endereço. O endereço de email não é tornado público e apenas será utilizado se desejar receber uma nova senha ou se desejar receber determinadas notícias ou notificações por email.
Senha: *
Confirmar senha: *
2. Informação Pessoal
Nome: *
O conteúdo deste campo é privado e não será exibido publicamente.
Apelido:
O conteúdo deste campo é privado e não será exibido publicamente.
País ou zona de residência:
O conteúdo deste campo é privado e não será exibido publicamente.
Telefone:
O conteúdo deste campo é privado e não será exibido publicamente.
Data de nascimento:
O conteúdo deste campo é privado e não será exibido publicamente.
3. Avatar
Carregar fotografia:
A sua fotografia. A dimensão máxima é de pixeis e tamanho de 512 kB.

Deve utilizar uma fotografia sua, não utilize fotografias de outras pessoas!

4. Captcha
Este passo pretende desabilitar automatismo de spam.
Qual é o código que vê na imagem?: *
Introduza os caracteres apresentados na imagem.
5. Termos e condições de utilização

Leia atentamente este documento. Ele contém informações importantes referentes ao acesso a este site bem como ao respectivos termos de utilização.

### Termos e Condições de Utilização

O site www.dnoticias.pt é propriedade da Empresa Diário de Notícias, Lda. e respeita a sua política editorial.

O uso que um utilizador fizer de qualquer informação, conteúdos, produtos ou serviços disponibilizados no site ou acessíveis através dele, está condicionado pelos Termos e Condições de Utilização, Política de Privacidade, além das normas legais e Códigos de Conduta que a Empresa Diário de Notícias, Lda. venha a subscrever.

A Empresa Diário de Notícias, Lda. e (ou) seus administradores, directores e funcionários não são responsáveis por quaisquer danos que possam ser causados pela utilização do serviço, incluindo a contaminação de vírus ou utilização indevida da imagem do site por terceiros.

Os menores de 18 anos deverão obter autorização dos pais ou de quem exerce o poder paternal, antes de acederem ou disponibilizarem dados pessoais no site.

A Empresa Diário de Notícias, Lda. não autorizará a utilização do site por menores de 18 sem autorização dos pais, sempre que tiver conhecimento desse facto.

Os utilizadores do site declaram conhecer e aceitar os termos e condições de utilização do site, respeitando os mesmos e responsabilizando-se por actos ou omissões que os contrariem.

### Critérios de Publicação

O DIÁRIO reserva-se o direito de não publicar comentários, artigos, fotografias ou vídeos, cujo conteúdo:
• Seja considerado racista, xenófobo, difamatório
• Incluam acusações de carácter criminal, mensagens que apelem à violência, ou à violação das leis em vigor
• Utilizem linguagem inapropriada ou insultuosa
• Cujos conteúdos possam ferir susceptibilidades
• Façam menção a matérias ilegais
• Cujos conteúdos sejam incompreensíveis ou codificados
• Contenham mensagens com fins comerciais ou de publicidade
• Contenham vírus de software ou qualquer outro código informático, ficheiros ou programas cujo objectivo seja interromper, destruir ou limitar a funcionalidade de qualquer computador ou sistema informático (hardware e software) ou equipamento de telecomunicações

Os comentários e os artigos enviados não são editados pelo DIÁRIO, nem sujeitos a qualquer tipo de alteração.

Não poderá ser imputada qualquer responsabilidade à Empresa Diário de Notícias, Lda. pela inserção de material não original enviado pelos utilizadores. Leia com atenção Direitos de Autor.

### Direitos de Autor e de Propriedade Intelectual

Os conteúdos disponíveis no site www.dnoticias.pt pertencem à Empresa Diário de Notícias, Lda. não podendo ser reproduzidos ou utilizados, seja para que fim for, sem a autorização prévia desta, incorrendo, nomeadamente em ilícito criminal quem violar a presente regra, salvo todos os conteúdos disponibilizados no site para partilha e download.

O utilizador que pretenda publicar, inserir ou divulgar qualquer tipo de material, seja artigos, fotografias, vídeos ou outro(s), assegurará à Empresa Diário de Notícias, Lda. que tem o direito de o fazer, detendo todos direitos de autor, quer morais quer patrimoniais e de propriedade intelectual sobre os mesmos.

Caso se venha a verificar que o mesmo não corresponde à verdade, o utilizador fica responsável pelos prejuízos causados quer a terceiros quer à Empresa Diário de Notícias, Lda., devendo indemnizar os mesmos, bem como assumir o pagamento de qualquer coima, multa ou outra sanção que seja aplicada à Empresa Diário de Notícias, Lda. e que resulte da conduta do utilizador.

Não poderá ser imputada qualquer responsabilidade à Empresa Diário de Notícias, Lda. pela inserção de material não original enviado pelos utilizadores.

Assiste à Empresa Diário de Notícias, Lda. o direito de regresso contra o(s) utilizador(s), caso lhe seja aplicada qualquer coima, multa, indemnização ou resultem para si encargos resultantes do incumprimento legal ou contratual do conteúdo do material inserido ou enviado pelos utilizadores do site.

A Empresa Diário de Notícias, Lda. reserva-se o direito de retirar do site, suspender, destruir ou não divulgar qualquer material susceptível de não respeitar as regras legais, designadamente o Código de Direitos de Autor e Direitos Conexos.

O utilizador, com o envio e (ou) a inserção de conteúdos no site, quer sejam artigos, fotografias, vídeos ou outros, transfere todos os direitos de autor ou de propriedade intelectual sobre os mesmos para a Empresa Diário de Notícias, Lda..

O utilizador aceita que todo o material por si enviado ou inserido no site poderá ser publicado, divulgado ou de qualquer forma dado conhecimento através das várias formas de comunicação da Empresa Diário de Notícias, Lda., designadamente através do site ou do jornal impresso.

Pela utilização ou divulgação de quaisquer textos, comentários, fotografias, vídeos ou outras imagens existente(s) no site ou no suporte papel, o utilizador não adquire qualquer direito nem sobre a Empresa Diário de Notícias, Lda. nem sobre qualquer informação, produto ou serviço disponibilizado nele ou através dele.

A Empresa Diário de Notícias, Lda., reserva-se o direito de suspender, alterar os conteúdos ou forma de apresentação, alterar a designação ou mesmo encerrar o site, quando o considerar de acordo com a sua estratégia ou necessidades técnicas, sem necessidade de pré-aviso e pelo período que entender necessário, não lhe sendo exigível qualquer responsabilidade ou indemnização.

### Política de Privacidade

A Empresa Diário de Notícias, Lda. assegura a todos os utilizadores do site o Direito de informação, o Direito de acesso, Direito de rectificação e eliminação e qualquer outro Direito com consagração constitucional. A Empresa Diário de Notícias, Lda., assegura a todos os utilizadores do site o direito de aceder aos dados que sejam registados sobre si, sem restrições, sem demoras ou custos excessivos.

O utilizador do site não se opõe a que os seus dados sejam utilizados para fins de marketing do grupo Empresa Diário de Notícias, Lda., dando a sua autorização expressa para esse fim.

Reconhecendo a importância da internet como meio de divulgação e comunicação, a Empresa Diário de Notícias, Lda. garante aos utilizadores dos seus serviços e visitantes das suas páginas, a confidencialidade dos seus dados.

O utilizador do site sabe que esta declaração de garantia de privacidade de dados aplica-se exclusivamente ao serviço da Empresa Diário de Notícias, Lda..

Os dados solicitados destinam-se a manter um relacionamento mais próximo com os utilizadores do site, respondendo às suas necessidades ou pedidos com mais eficácia, permitindo elaborar fóruns, votações, registos de assinantes, conhecer as suas preferências e elaborar conteúdos de acordo com essas necessidades, respeitando sempre o seu estatuto editorial, divulgar de iniciativas, projectos e, fundamentalmente, transmitir com celeridade a informação.

Se a Empresa Diário de Notícias, Lda. recorrer a outra empresa para auxiliar ou processar o tratamento de dados pessoais, exigirá que respeitem a política de privacidade e utilizem as técnicas de segurança adequadas.

Qualquer violação ou tratamento indevido de dados, não poderá ser imputado à Empresa Diário de Notícias, Lda..

Os dados dos utilizadores e visitantes serão facultados quando existam indícios de que houve utilização abusiva da imagem, ilícitos criminais, violação de direitos de autor, de protecção intelectual e (ou) industrial de terceiros e (ou) em caso de notificação por parte da Comissão Nacional de Protecção de Dados, Tribunais ou outra entidade, desde que com competência legal.

A Empresa Diário de Notícias, Lda. assegura a todos os utilizadores do site o direito de exigir que os dados a seu respeito sejam exactos e actuais, podendo solicitar a sua rectificação.

Sempre que o utilizador pretenda exercer os seus direitos poderá contactar directamente a Empresa Diário de Notícias, Lda..

### Utilização de cookies pela Empresa Diário de Notícias, Lda.

Os cookies são pequenos ficheiros de texto enviados pelos sites que visita e que são armazenados no seu computador. São amplamente utilizados para o funcionamento dos sites, ou para aumentar a eficiência dos mesmos, bem como para fornecer informações aos proprietários do site.

Os cookies são estritamente necessários para aceder a áreas privadas do utilizador. Sem estes cookies, os serviços que tenha requerido não podem ser prestados. Além destes, são utilizados cookies analíticos, funcionais, publicidade e terceiros.

### Entidade responsável pelo tratamento dos dados

A entidade responsável pelo tratamento da base de dados é a Empresa Diário de Notícias, Lda., com domicílio em Rua Dr. Fernão de Ornelas, 56/3º, Apartado 421 - 9001-957 Funchal.

A Empresa Diário de Notícias, Lda. pode actualizar os termos de utilização e (ou) a política de privacidade, atenta às imposições legais ou devido à evolução tecnológica.

### Do foro competente

Os Termos de Utilização, a Política de Privacidade do site, bem como qualquer conflito quanto aos direitos de autor e (ou) de propriedade intelectual, estão sujeitos às normas legais portuguesas.

Qualquer litígio será dirimido, preferencialmente por uma comissão arbitrária. Caso o mesmo não se mostre viável, o litígio será resolvido junto dos tribunais portugueses, o que o utilizador declara aceitar.

Li e aceito os termos e condições de utilização *